@@ -18,6 +18,7 @@ package org.uberfire.ext.wires.client.demo.grids;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Set;
+
 import javax.annotation.PostConstruct;
 import javax.enterprise.context.Dependent;
 import javax.inject.Inject;
@@ -341,9 +342,9 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
                                                                                         100);
         grid3.appendColumn(grid3Column2);
         for (int rowIndex = 0; rowIndex < GRID4_ROWS; rowIndex++) {
-            grid3.setCell(rowIndex,
-                          3,
-                          new BaseGridCellValue<String>("(" + 2 + ", " + rowIndex + ")"));
+            grid3.setCellValue(rowIndex,
+                               3,
+                               new BaseGridCellValue<String>("(" + 2 + ", " + rowIndex + ")"));
         }
 
         //Add DOM Column - CheckBox
@@ -357,9 +358,9 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
         grid3Column3.setFloatable(true);
         grid3.appendColumn(grid3Column3);
         for (int rowIndex = 0; rowIndex < GRID4_ROWS; rowIndex++) {
-            grid3.setCell(rowIndex,
-                          4,
-                          new BaseGridCellValue<Boolean>(Math.random() < GridDataFactory.FILL_FACTOR));
+            grid3.setCellValue(rowIndex,
+                               4,
+                               new BaseGridCellValue<Boolean>(Math.random() < GridDataFactory.FILL_FACTOR));
         }
 
         //Add DOM Column - ListBox
@@ -373,9 +374,9 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
                                                                                          100);
         grid3.appendColumn(grid3Column4);
         for (int rowIndex = 0; rowIndex < GRID4_ROWS; rowIndex++) {
-            grid3.setCell(rowIndex,
-                          5,
-                          new BaseGridCellValue<String>(rowIndex % 2 == 0 ? "one" : "two"));
+            grid3.setCellValue(rowIndex,
+                               5,
+                               new BaseGridCellValue<String>(rowIndex % 2 == 0 ? "one" : "two"));
         }
 
         gridWidget3.setLocation(new Point2D(1050,
@@ -401,35 +402,39 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
                                                               }
 
                                                               @Override
-                                                              public Group renderSelector(final double width,
-                                                                                          final double height,
-                                                                                          final BaseGridRendererHelper.RenderingInformation renderingInformation) {
-                                                                  final Group g = new Group();
-                                                                  final Bounds bounds = getSelectorBounds(width,
-                                                                                                          height,
-                                                                                                          renderingInformation);
+                                                              public RendererCommand renderSelector(final double width,
+                                                                                                    final double height,
+                                                                                                    final BaseGridRendererHelper.RenderingInformation renderingInformation) {
+                                                                  return (RenderSelectorCommand) (rc) -> {
+                                                                      if (!rc.isSelectionLayer()) {
+                                                                          final Group g = new Group();
+                                                                          final Bounds bounds = getSelectorBounds(width,
+                                                                                                                  height,
+                                                                                                                  renderingInformation);
 
-                                                                  final MultiPath selector = theme.getSelector()
-                                                                          .M(bounds.getX() + 0.5,
-                                                                             bounds.getY() + 0.5)
-                                                                          .L(bounds.getX() + 0.5,
-                                                                             height)
-                                                                          .L(width,
-                                                                             height)
-                                                                          .L(width,
-                                                                             bounds.getY() + 0.5)
-                                                                          .L(bounds.getX() + 0.5,
-                                                                             bounds.getY() + 0.5)
-                                                                          .setListening(false);
-                                                                  g.add(selector);
+                                                                          final MultiPath selector = theme.getSelector()
+                                                                                  .M(bounds.getX() + 0.5,
+                                                                                     bounds.getY() + 0.5)
+                                                                                  .L(bounds.getX() + 0.5,
+                                                                                     height)
+                                                                                  .L(width,
+                                                                                     height)
+                                                                                  .L(width,
+                                                                                     bounds.getY() + 0.5)
+                                                                                  .L(bounds.getX() + 0.5,
+                                                                                     bounds.getY() + 0.5)
+                                                                                  .setListening(false);
+                                                                          g.add(selector);
 
-                                                                  final Text t = theme.getHeaderText();
-                                                                  t.setText(translationService.getTranslation(WiresGridsDemoConstants.GridWidget4_Selector_Caption));
-                                                                  t.setX(bounds.getWidth() / 2);
-                                                                  t.setY(bounds.getY() - renderingInformation.getHeaderRowsYOffset() / 2);
-                                                                  g.add(t);
+                                                                          final Text t = theme.getHeaderText();
+                                                                          t.setText(translationService.getTranslation(WiresGridsDemoConstants.GridWidget4_Selector_Caption));
+                                                                          t.setX(bounds.getWidth() / 2);
+                                                                          t.setY(bounds.getY() - renderingInformation.getHeaderRowsYOffset() / 2);
+                                                                          g.add(t);
 
-                                                                  return g;
+                                                                          rc.getGroup().add(g);
+                                                                      }
+                                                                  };
                                                               }
 
                                                               private Bounds getSelectorBounds(final double width,
@@ -475,15 +480,15 @@ public class WiresGridsDemoPresenter implements WiresGridsDemoView.Presenter {
                 switch (columnIndex) {
                     case 0:
                         if (Math.random() > 0.5) {
-                            grid4.setCell(rowIndex,
-                                          columnIndex,
-                                          new BaseGridCellValue<String>("(" + columnIndex + ", " + rowIndex + ")"));
+                            grid4.setCellValue(rowIndex,
+                                               columnIndex,
+                                               new BaseGridCellValue<String>("(" + columnIndex + ", " + rowIndex + ")"));
                         }
                         break;
                     case 1:
-                        grid4.setCell(rowIndex,
-                                      columnIndex,
-                                      new BaseGridCellValue<Boolean>(Math.random() < 0.5));
+                        grid4.setCellValue(rowIndex,
+                                           columnIndex,
+                                           new BaseGridCellValue<Boolean>(Math.random() < 0.5));
                         break;
                 }
             }
